@@ -390,6 +390,11 @@ def parse_arguments(args=None):
         "in S3. Can be specified using the key ID on its own or using the full ARN for "
         "the key. Only allowed if `-e/--encryption` is set to `aws:kms`.",
     )
+    s3_arguments.add_argument(
+        "--aws-region",
+        help="The name of the AWS region containing the EC2 VM and storage volumes "
+        "defined by the --snapshot-instance and --snapshot-disk arguments.",
+    )
     azure_arguments.add_argument(
         "--encryption-scope",
         help="The name of an encryption scope defined in the Azure Blob Storage "
