@@ -47,7 +47,7 @@ def _make_s3_cloud_interface(config, cloud_interface_kwargs):
 
     cloud_interface_kwargs.update(
         {
-            "profile_name": config.profile,
+            "profile_name": config.aws_profile,
             "endpoint_url": config.endpoint_url,
             "read_timeout": config.read_timeout,
         }
@@ -194,6 +194,10 @@ def get_snapshot_interface(config):
             resource_group=config.azure_resource_group,
             credential=_get_azure_credential(config.azure_credential),
         )
+    elif config.cloud_provider == "aws-s3":
+        from barman.cloud_providers.aws_s3 import AwsCloudSnapshotInterface
+
+        return AwsCloudSnapshotInterface(config.aws_profile, config.aws_region)
     else:
         raise CloudProviderUnsupported(
             "No snapshot provider for cloud provider: %s" % config.cloud_provider
@@ -237,6 +241,12 @@ def get_snapshot_interface_from_server_config(server_config):
             resource_group=server_config.azure_resource_group,
             credential=_get_azure_credential(server_config.azure_credential),
         )
+    elif server_config.snapshot_provider == "aws":
+        from barman.cloud_providers.aws_s3 import AwsCloudSnapshotInterface
+
+        return AwsCloudSnapshotInterface(
+            server_config.aws_profile, server_config.aws_region
+        )
     else:
         raise CloudProviderUnsupported(
             "Unsupported snapshot provider: %s" % server_config.snapshot_provider
@@ -294,6 +304,20 @@ def get_snapshot_interface_from_backup_info(backup_info, config=None):
             resource_group=resource_group,
             credential=_get_azure_credential(config.azure_credential),
         )
+    elif backup_info.snapshots_info.provider == "aws":
+        from barman.cloud_providers.aws_s3 import AwsCloudSnapshotInterface
+
+        # When creating a snapshot interface for existing backups we use the region
+        # from the backup_info, unless a region is set in the config in which case the
+        # config region takes precedence.
+        region = None
+        profile = None
+        if config is not None and hasattr(config, "aws_region"):
+            region = config.aws_region
+            profile = config.aws_profile
+        if region is None:
+            region = backup_info.snapshots_info.region
+        return AwsCloudSnapshotInterface(profile, region)
     else:
         raise CloudProviderUnsupported(
             "Unsupported snapshot provider in backup info: %s"
@@ -321,6 +345,12 @@ def snapshots_info_from_dict(snapshots_info):
         )
 
         return AzureSnapshotsInfo.from_dict(snapshots_info)
+    elif "provider" in snapshots_info and snapshots_info["provider"] == "aws":
+        from barman.cloud_providers.aws_s3 import (
+            AwsSnapshotsInfo,
+        )
+
+        return AwsSnapshotsInfo.from_dict(snapshots_info)
     else:
         raise CloudProviderUnsupported(
             "Unsupported snapshot provider in backup info: %s"
