@@ -429,6 +429,9 @@ class ServerConfig(object):
         "active",
         "archiver",
         "archiver_batch_size",
+        "autogenerate_manifest",
+        "aws_profile",
+        "aws_region",
         "azure_credential",
         "azure_resource_group",
         "azure_subscription_id",
@@ -517,6 +520,9 @@ class ServerConfig(object):
     BARMAN_KEYS = [
         "archiver",
         "archiver_batch_size",
+        "autogenerate_manifest",
+        "aws_profile",
+        "aws_region",
         "azure_credential",
         "azure_resource_group",
         "azure_subscription_id",
@@ -591,6 +597,7 @@ class ServerConfig(object):
         "active": "true",
         "archiver": "off",
         "archiver_batch_size": "0",
+        "autogenerate_manifest": "false",
         "backup_directory": "%(barman_home)s/%(name)s",
         "backup_method": "rsync",
         "backup_options": "",
@@ -629,6 +636,7 @@ class ServerConfig(object):
         "active": parse_boolean,
         "archiver": parse_boolean,
         "archiver_batch_size": int,
+        "autogenerate_manifest": parse_boolean,
         "backup_compression": parse_backup_compression,
         "backup_compression_format": parse_backup_compression_format,
         "backup_compression_level": int,
