@@ -128,6 +128,12 @@ class SnapshotBackupException(BackupException):
     """
 
 
+class SnapshotInstanceNotFoundException(SnapshotBackupException):
+    """
+    Raised when the VM instance related to a snapshot backup cannot be found
+    """
+
+
 class SyncError(SyncException):
     """
     Synchronisation error
@@ -335,6 +341,12 @@ class BadXlogSegmentName(WALFileException):
     """
 
 
+class BadXlogPrefix(WALFileException):
+    """
+    Exception for a bad xlog prefix
+    """
+
+
 class BadHistoryFileContents(WALFileException):
     """
     Exception for a corrupted history file
